@@ -1,20 +1,20 @@
 box::use(
-  shiny[
+  shiny[           # nolint
+    actionButton,
     bootstrapPage,
+    isolate,
+    moduleServer,
     NS,
+    observe,
+    observeEvent,
+    renderText,
     tags,
     textInput,
-    actionButton,
-    observeEvent,
-    textOutput,
-    moduleServer,
-    observe,
-    renderText,
-    isolate
-  ]
+    textOutput
+  ],
 )
 
-box::use(app / logic / say_hello[say_hello])
+box::use(app/logic/say_hello[say_hello], )
 
 #' @export
 ui <- function(id) {
