@@ -1,9 +1,9 @@
 box::use(
+  rhino[log, react_component],
   shiny,
-  rhino[log, react_component]
 )
 
-box::use(app / view / hello)
+box::use(app/view/hello, )
 
 Box <- react_component("Box") # nolint object_name_linter
 
